@@ -10,9 +10,9 @@ describe 'swift::proxy' do
       let :pre_condition do
         "class { memcached: max_memory => 1}
          class { swift: swift_hash_path_suffix => string }
-         include ::swift::proxy::healthcheck
-         include ::swift::proxy::cache
-         include ::swift::proxy::tempauth"
+         include swift::proxy::healthcheck
+         include swift::proxy::cache
+         include swift::proxy::tempauth"
       end
 
       describe 'without the proxy local network ip address being specified' do
@@ -63,6 +63,8 @@ describe 'swift::proxy' do
         it { should contain_swift_proxy_config('app:proxy-server/set log_level').with_value('INFO') }
         it { should contain_swift_proxy_config('app:proxy-server/set log_address').with_value('/dev/log') }
         it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('true') }
+        it { should contain_swift_proxy_config('app:proxy-server/object_chunk_size').with_value('65536') }
+        it { should contain_swift_proxy_config('app:proxy-server/client_chunk_size').with_value('65536') }
         it { should contain_swift_proxy_config('app:proxy-server/allow_account_management').with_value('true') }
         it { should contain_swift_proxy_config('app:proxy-server/account_autocreate').with_value('true') }
         it { should contain_swift_proxy_config('app:proxy-server/max_containers_per_account').with_value(0) }
@@ -80,9 +82,9 @@ describe 'swift::proxy' do
               class { memcached: max_memory => 1}
               class { swift: swift_hash_path_suffix => string }
               swift_proxy_config { 'foo/bar': value => 'foo' }
-              include ::swift::proxy::healthcheck
-              include ::swift::proxy::cache
-              include ::swift::proxy::tempauth
+              include swift::proxy::healthcheck
+              include swift::proxy::cache
+              include swift::proxy::tempauth
             "
           end
 
@@ -93,7 +95,7 @@ describe 'swift::proxy' do
           let :pre_condition do
             "class { memcached: max_memory => 1}
              class { swift: swift_hash_path_suffix => string }
-             include ::swift::proxy::swauth"
+             include swift::proxy::swauth"
           end
 
           let :params do
@@ -106,11 +108,14 @@ describe 'swift::proxy' do
               :account_autocreate         => false,
               :log_level                  => 'DEBUG',
               :log_name                   => 'swift-proxy-server',
+              :object_chunk_size          => '8192',
+              :client_chunk_size          => '8192',
               :max_containers_per_account => 10,
               :max_containers_whitelist   => 'project1,project2',
               :read_affinity              => 'r1z1=100, r1=200',
               :write_affinity             => 'r1',
               :write_affinity_node_count  => '2 * replicas',
+              :client_timeout             => '120',
               :node_timeout               => '20',
               :cors_allow_origin          => 'http://foo.bar:1234,https://foo.bar',
             }
@@ -127,6 +132,7 @@ describe 'swift::proxy' do
           it { should contain_swift_proxy_config('DEFAULT/log_address').with_value('/dev/log') }
           it { should contain_swift_proxy_config('DEFAULT/cors_allow_origin').with_value('http://foo.bar:1234,https://foo.bar') }
           it { should contain_swift_proxy_config('DEFAULT/strict_cors_mode').with_value('true') }
+          it { should contain_swift_proxy_config('DEFAULT/client_timeout').with_value('120') }
           it { should contain_swift_proxy_config('pipeline:main/pipeline').with_value('swauth proxy-server') }
           it { should contain_swift_proxy_config('app:proxy-server/use').with_value('egg:swift#proxy') }
           it { should contain_swift_proxy_config('app:proxy-server/set log_name').with_value('swift-proxy-server') }
@@ -134,6 +140,8 @@ describe 'swift::proxy' do
           it { should contain_swift_proxy_config('app:proxy-server/set log_level').with_value('DEBUG') }
           it { should contain_swift_proxy_config('app:proxy-server/set log_address').with_value('/dev/log') }
           it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('true') }
+          it { should contain_swift_proxy_config('app:proxy-server/object_chunk_size').with_value('8192') }
+          it { should contain_swift_proxy_config('app:proxy-server/client_chunk_size').with_value('8192') }
           it { should contain_swift_proxy_config('app:proxy-server/allow_account_management').with_value('false') }
           it { should contain_swift_proxy_config('app:proxy-server/account_autocreate').with_value('false') }
           it { should contain_swift_proxy_config('app:proxy-server/max_containers_per_account').with_value(10) }
@@ -193,7 +201,7 @@ describe 'swift::proxy' do
             let :pre_condition do
               "class { memcached: max_memory => 1}
                class { swift: swift_hash_path_suffix => string }
-               include ::swift::proxy::swauth"
+               include swift::proxy::swauth"
             end
 
             it { should contain_swift_proxy_config('DEFAULT/bind_port').with_value('80') }
@@ -230,7 +238,7 @@ describe 'swift::proxy' do
           [:account_autocreate, :allow_account_management].each do |param|
             it "should fail when #{param} is not passed a boolean" do
               params[param] = 'false'
-              should raise_error(Puppet::Error, /is not a boolean/)
+              should raise_error(Puppet::Error)
             end
           end
 
@@ -245,6 +253,18 @@ describe 'swift::proxy' do
             should raise_error(Puppet::Error, /write_affinity_node_count requires write_affinity/)
           end
         end
+
+        describe 'when unsupported swift3 is used' do
+          let :params do
+            {
+              :pipeline => ['swift3', 'swauth', 'proxy-server']
+            }
+          end
+
+          it 'should fail if swift3 is included in pipeline' do
+            should raise_error(Puppet::Error)
+          end
+        end
       end
     end
   end
@@ -259,9 +279,9 @@ describe 'swift::proxy' do
     let :pre_condition do
       "class { memcached: max_memory => 1}
        class { swift: swift_hash_path_suffix => string }
-       include ::swift::proxy::healthcheck
-       include ::swift::proxy::cache
-       include ::swift::proxy::tempauth"
+       include swift::proxy::healthcheck
+       include swift::proxy::cache
+       include swift::proxy::tempauth"
     end
 
 
